#!/usr/bin/env raku

use lib 'lib';
use Terminal::ANSI;

underline; say 'underline'; text-reset;
say "";
italic; say 'italic'; text-reset;
bold; say 'bold'; text-reset;
blink; say 'blink'; text-reset;
strike; say 'strike'; text-reset;
for 11..19 {
  alt-font($_); say "alt font $_"; text-reset;
}

text-reset;
put 'bye';
