#!/usr/bin/env raku

use Terminal::ANSI;

clear-screen;
print-at 1,1, '*';
my $cols = qx[tput cols];
for 1..$cols {
  print-at 3,$_, $_ %% 5 ?? '|' !! '.';
}
for 1..$cols {
  print-at 4,$_, $_ % 10;
}
for 1..$cols {
  print-at 2,$_, $_ %% 10 ?? '|' !! '.';
}
print-at 5, 1, 'bye';
print "\n";
