#!/usr/bin/env raku

use Terminal::ANSI;

save-screen;
clear-screen;
home;
set-scroll-region(3,7);
print-at 1,1, "1,1";
print-at 2,1, "---------";
print-at 8,1, "---------";
move-to 3,1;
for 1..20 {
  print "\n" unless $_ == 1;
  print "this is line $_";
  sleep 0.4;
}
reset-scroll-region;
restore-screen;
