#!/usr/bin/env raku

use Terminal::ANSI::OO :t;

put t.save-screen;
put t.clear-screen;
put t.home;

put t.red ~ 'red';
put t.green ~ 'green';
put t.bright-blue ~ 'bright blue';
put t.bg-yellow ~ t.blue ~ 'blue on yellow';
put t.color(100) ~ t.bg-color(150) ~ '100 on 150';
put t.color(0,0,255) ~ t.bg-color(255,255,0) ~ '0,0,255 on 255,255,0';

put t.text-reset;

prompt "press return>";

put t.restore-screen;
