#!/usr/bin/env raku

use Terminal::ANSI::OO 'ta';

put ta.save-screen;
put ta.clear-screen;
put ta.home;

put ta.red ~ 'red';
put ta.green ~ 'green';
put ta.bright-blue ~ 'bright blue';
put ta.bg-yellow ~ ta.blue ~ 'blue on yellow';
put ta.color(100) ~ ta.bg-color(150) ~ '100 on 150';

put ta.text-reset;

prompt "press return>";

put ta.restore-screen;
