#!/usr/bin/env raku

use lib 'lib';
use Terminal::ANSI;

clear-screen;
print-at 1,1, 'testing!';
move-to(2,1) && put 'row 2, column 1';
move-to(10,20) && put 'row 10, column 20';
home;
set-scroll-region(10,20);
move-to(10);
.put for 1..20;
reset-scroll-region;
scroll-down;
set-scroll-region(22,25);
move-to(22);
.put for 100..150;
scroll-up;
scroll-up(2);
scroll-down(2);
reset-scroll-region;
hide-cursor;
show-cursor;
save-screen;
restore-screen;
print-at 25,1, 'line 25';
cursor-off;
cursor-on;
cursor-down;
cursor-down(5);
put 'bye';
