#!/usr/bin/env raku

use Terminal::ANSI;

clear-screen;
print-at 1,1, '1,1';
cursor-right(5);
print 'a) right 5';
cursor-down(2);
print 'b) down 2';
cursor-down(10);
cursor-left(10);
print 'c) down 10, left 10';
cursor-down(1);
cursor-left(17);
print 'd) down 1, left 17';
cursor-next-line(2);
print 'e) next line 2';
cursor-prev-line(3);
print 'f) prev line 3';
cursor-next-line(15);
print 'g) next line 15';
print "\n";
print "\n";
